==> core-1.0.59.zip: misc/config.php <==
<?php


function getDbInfo(){
    // MySQl Databse Connection Info 
    $result['host']    = 'localhost';
    $result['user']    = 'abc';
    $result['pass']    = 'def';
    $result['sche']    = 'abc';

    $result['scheGen'] = $result['sche'];

return $result;

}

function debugModeValue(){
    return "CSD";
}

function getCompanyInfo(){
    $companyInfo['companyName']       = "White Lable CMS"; 
    $companyInfo['adminRecipient']    = "Blank@no-reply.co.uk";
    return $companyInfo;
}

function setStripeKey(&$inputData): void{
    $inputData['secure']['stripeSecretKey'] = "sk_test_51Rq7ZNDMt3vZ38M1DFArbbUwQJ5N7Is1yw1xsztxwdE3iZs0pEJr04eeUgr7sMglchG9uKx69t6cRthwNXZtCf8y00w42rwBsJ";
    $inputData['secure']['stripePublishableKey'] = "pk_test_51Rq7ZNDMt3vZ38M1LbXeYRV2LtrMnBmr3ou9zGXfQRMDfeWTLN6sd7nC6j1CmDOLrrIBupsjzO0DSKojmenK5mi400uPh7ID0I";
}

function turnstileSecret(&$inputData): void{
    $inputData['secure']['turnstileSecret'] = "0x4AAAAAAAD5f0b6f8e3e2b7e123b6e5e2b3b4b5";
}

function applyOrderCodeConfig(array &$inputData): void
{
    // Put everything in one place
    $inputData['secure']['orderCode'] = [
        'ORDER_CODE_PREFIX'      => 'C',
        'ORDER_CODE_PAYLOAD_LEN' => 7,

        // includes 0/1, excludes I O l o
        'ORDER_CODE_ALPHABET' => '0123456789ABCDEFGHJKLMNPQRSTUVWXYZabcdefghijkmnpqrstuvwxyz',

        // Scramble secrets (store securely; keep stable forever)
        'ORDER_CODE_SCRAMBLE_A' => 5,          // not divisible by 2 or 29
        'ORDER_CODE_SCRAMBLE_B' => 123456789,  // 0 <= B < base^payloadLen
    ];
}

// error_log($host." ".$user." ".$pass." ".$sche)

?>

==> core-2.0.30.zip: misc/config.php <==
<?php


function getDbInfo(){
    // MySQl Databse Connection Info 
    $result['host']    = 'localhost';
    $result['user']    = 'abc';
    $result['pass']    = 'def';
    $result['sche']    = 'abc';

    $result['scheGen'] = $result['sche'];

return $result;

}

function debugModeValue(){
    return "CSD";
}

function getCompanyInfo(){
    $companyInfo['companyName']       = "White Lable CMS"; 
    $companyInfo['adminRecipient']    = "Blank@no-reply.co.uk";
    return $companyInfo;
}

function setStripeKey(&$inputData): void{
    $inputData['secure']['stripeSecretKey'] = "sk_test_51Rq7ZNDMt3vZ38M1DFArbbUwQJ5N7Is1yw1xsztxwdE3iZs0pEJr04eeUgr7sMglchG9uKx69t6cRthwNXZtCf8y00w42rwBsJ";
    $inputData['secure']['stripePublishableKey'] = "pk_test_51Rq7ZNDMt3vZ38M1LbXeYRV2LtrMnBmr3ou9zGXfQRMDfeWTLN6sd7nC6j1CmDOLrrIBupsjzO0DSKojmenK5mi400uPh7ID0I";
}

function turnstileSecret(&$inputData): void{
    $inputData['secure']['turnstileSecret'] = "0x4AAAAAAAD5f0b6f8e3e2b7e123b6e5e2b3b4b5";
}

function applyOrderCodeConfig(array &$inputData): void
{
    // Put everything in one place
    $inputData['secure']['orderCode'] = [
        'ORDER_CODE_PREFIX'      => 'C',
        'ORDER_CODE_PAYLOAD_LEN' => 7,

        // includes 0/1, excludes I O l o
        'ORDER_CODE_ALPHABET' => '0123456789ABCDEFGHJKLMNPQRSTUVWXYZ',

        // Scramble secrets (store securely; keep stable forever)
        'ORDER_CODE_SCRAMBLE_A' => 5,          // not divisible by 2 or 29
        'ORDER_CODE_SCRAMBLE_B' => 123456789,  // 0 <= B < base^payloadLen
    ];
}

function unzipCred(): string {
    return 'PUT_A_LONG_RANDOM_SECRET_HERE';
}

function unzipWindowSeconds(): int {
    return 60;
}

function unzipAllowedFiles(): array {
    return ['deployment.zip', 'deployment-admin.zip', 'deployment-superadmin.zip'];
}

// error_log($host." ".$user." ".$pass." ".$sche)

?>
